@@ -19,14 +19,14 @@ sub render {
     $self->{stash} = {%{$self->stash}, %$args};
 
     # Template
-    unless ($self->stash->{template} || $self->stash->{template_path}) {
+    unless ($self->stash->{template}) {
 
         # Default template
         my $controller = $self->stash->{controller};
         my $action     = $self->stash->{action};
 
         # Nothing to render
-        return undef unless $controller && $action;
+        return unless $controller && $action;
 
         $self->stash->{template} = join '/', split(/-/, $controller), $action;
     }
@@ -38,12 +38,7 @@ sub render {
     return $self->app->renderer->render($self);
 }
 
-sub render_inner {
-    my $self = shift;
-    local $self->stash->{template}      = $self->stash->{inner_template};
-    local $self->stash->{template_path} = $self->stash->{inner_template_path};
-    return $self->render_partial(@_);
-}
+sub render_inner { delete shift->stash->{inner_template} }
 
 sub render_partial {
     my $self = shift;
@@ -105,13 +100,12 @@ L<MojoX::Dispatcher::Routes::Context> and implements the following new ones.
 
 =head2 C<render_inner>
 
-    $c->render_inner;
-    $c->render_inner(action => 'foo');
+    my $output = $c->render_inner;
 
 =head2 C<render_partial>
 
-    $c->render_partial;
-    $c->render_partial(action => 'foo');
+    my $output = $c->render_partial;
+    my $output = $c->render_partial(action => 'foo');
 
 =head2 C<url_for>
 
